% tel1.m
% fd, 05 novembre 2006, 05 mars 2025 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   clear ; format long 

fprintf ('test1 \n') ;
fprintf ('les equations d Euler indiquent qu une somme de 3 vecteurs unitaires est nulle \n') ;
fprintf ('si A et B sont deux des trois sommets qui parametrent le probleme \n') ;
fprintf ('et M un point de minimum, l angle des demi-droites MA,MB vaut 2*pi/3 \n') ;
fprintf ('alors M appartient a un arc de cercle qui passe par les points A et B, \n') ;
fprintf ('ensemble des points tel que l angle des demi-droites\n') ;
fprintf ('relatives a deux points donnes est egal a 2*pi/3\n') ;
fprintf ('ce probleme classique implemente dans ce programme est une variante  \n') ;
fprintf ('de la propriete que l angle au centre est le double de l angle inscrit   \n \n') ;

xa = 0 ; ya = 0 ; xb = 1 ; yb = 0 ; 
hold off 
plot ( [xa , xb] , [ya , yb ] , '*b;;') 
axis ( [ -.5 , 1.5 , -1  , 1 ] , 'square' ) ;
pause (1)

hold on ; 
xc = .5 ; yc = -1 / (2*sqrt(3)); rr=1/sqrt(3) ;


plot ( xc , yc , 'or;;') 

n=200 ; cercle=zeros(2,n+1) ; 
dth = 2*pi / (3*n) ; theta = pi/6 ; 
for j=1:n+1; 
cercle(1,j:j) = xc + rr*cos(theta) ; 
cercle(2,j:j) = yc + rr*sin(theta) ; 
theta = theta + dth ; end ; 
plot ( cercle(1:1,:) , cercle(2:2,:) , 'k;;') 


title ('l angle des demi-droites aux deux points bleus vaut 2*pi/3') ;
print('04-geometrie-cartesienne', '-djpg','-S891,630'); 
