% tel3.m
% fd, 05 novembre 2006, 05 mars 2025 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   clear ; format long 

fprintf ('test3 : arcs de cercle solutions d un probleme classique\n') ;
fprintf ('les sommets pour le probleme du central telephonique sont des etoiles bleues \n') ;
fprintf ('les centres des arcs de cercle sont des ronds rouges \n') ;



xa = 0 ; ya = 0 ; xb = 1 ; yb = 0 ;  xc = 0 ; yc = 1 ; 
hold off 
plot ( [xa  xb xc ] , [ya  yb yc ] , '*;;') 
axis ( [ -.5 , 1.2 , -.5  , 1.2 ] , 'square' ) ;
hold on ; 
n=arc(xa,ya,xb,yb) ; 
n=arc(xb,yb,xc,yc) ; 
n=arc(xc,yc,xa,ya) ; 

 
title ('solution geometrique du probleme du central telephonique pour trois sommets') ;

print('06-central-telephonique', '-djpg','-S891,630'); 
